==> zxing_lib-0.3.3.tar.gz: test/core/oned/rss/expanded/binary_util.dart <==
/*
 * Copyright (C) 2010 ZXing authors
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

/*
 * These authors would like to acknowledge the Spanish Ministry of Industry,
 * Tourism and Trade, for the support in the project TSI020301-2008-2
 * "PIRAmIDE: Personalizable Interactions with Resources on AmI-enabled
 * Mobile Dynamic Environments", led by Treelogic
 * ( http://www.treelogic.com/ ):
 *
 *   http://www.piramidepse.com/
 */

import 'package:zxing_lib/common.dart';

class BinaryUtil {
  static const Pattern ONE = "1";
  static const Pattern ZERO = "0";
  static const Pattern SPACE = " ";

  BinaryUtil();

  /*
  * Constructs a BitArray from a String like the one returned from BitArray.toString()
  */
  static BitArray buildBitArrayFromString(String data) {
    String dotsAndXs = data.replaceAll(ONE, "X").replaceAll(ZERO, ".");
    BitArray binary = BitArray(dotsAndXs.replaceAll(SPACE, "").length);
    int counter = 0;

    for (int i = 0; i < dotsAndXs.length; ++i) {
      if (i % 9 == 0) {
        // spaces
        if (dotsAndXs[i] != ' ') {
          throw Exception("space expected");
        }
        continue;
      }

      String currentChar = dotsAndXs[i];
      if (currentChar == 'X' || currentChar == 'x') {
        binary.set(counter);
      }
      counter++;
    }
    return binary;
  }

  static BitArray buildBitArrayFromStringWithoutSpaces(String data) {
    StringBuilder sb = StringBuilder();
    String dotsAndXs = data.replaceAll(ONE, "X").replaceAll(ZERO, ".");
    int current = 0;
    while (current < dotsAndXs.length) {
      sb.write(' ');
      for (int i = 0; i < 8 && current < dotsAndXs.length; ++i) {
        sb.write(dotsAndXs[current]);
        current++;
      }
    }
    return buildBitArrayFromString(sb.toString());
  }
}

==> zxing_lib-0.9.0.tar.gz: test/core/oned/rss/expanded/binary_util.dart <==
/*
 * Copyright (C) 2010 ZXing authors
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

/*
 * These authors would like to acknowledge the Spanish Ministry of Industry,
 * Tourism and Trade, for the support in the project TSI020301-2008-2
 * "PIRAmIDE: Personalizable Interactions with Resources on AmI-enabled
 * Mobile Dynamic Environments", led by Treelogic
 * ( http://www.treelogic.com/ ):
 *
 *   http://www.piramidepse.com/
 */

import 'package:zxing_lib/common.dart';

class BinaryUtil {
  static const Pattern ONE = '1';
  static const Pattern ZERO = '0';
  static const Pattern SPACE = ' ';

  BinaryUtil();

  /*
  * Constructs a BitArray from a String like the one returned from BitArray.toString()
  */
  static BitArray buildBitArrayFromString(String data) {
    final dotsAndXs = data.replaceAll(ONE, 'X').replaceAll(ZERO, '.');
    final binary = BitArray(dotsAndXs.replaceAll(SPACE, '').length);
    int counter = 0;

    for (int i = 0; i < dotsAndXs.length; ++i) {
      if (i % 9 == 0) {
        // spaces
        if (dotsAndXs[i] != ' ') {
          throw Exception('space expected');
        }
        continue;
      }

      final currentChar = dotsAndXs[i];
      if (currentChar == 'X' || currentChar == 'x') {
        binary.set(counter);
      }
      counter++;
    }
    return binary;
  }

  static BitArray buildBitArrayFromStringWithoutSpaces(String data) {
    final sb = StringBuilder();
    final dotsAndXs = data.replaceAll(ONE, 'X').replaceAll(ZERO, '.');
    int current = 0;
    while (current < dotsAndXs.length) {
      sb.write(' ');
      for (int i = 0; i < 8 && current < dotsAndXs.length; ++i) {
        sb.write(dotsAndXs[current]);
        current++;
      }
    }
    return buildBitArrayFromString(sb.toString());
  }
}
